``InvertedSymmetricalLogTransform.invlinthresh``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The ``invlinthresh`` attribute of `.InvertedSymmetricalLogTransform` is
deprecated. Use the ``.inverted().transform(linthresh)`` method instead.
